@@ -11,7 +11,11 @@ handleResponse <- function(response, jsonFilter = NULL) {
   # json responses
   if (isContentType(response, "application/json")) {
 
-    json <- RJSONIO::fromJSON(response$content, simplify = FALSE)
+    if (nzchar(response$content)) {
+      json <- jsonlite::fromJSON(response$content, simplifyVector = FALSE)
+    } else {
+      json <- list()
+    }
 
     if (response$status %in% 200:399)
       if (!is.null(jsonFilter))
@@ -28,9 +32,9 @@ handleResponse <- function(response, jsonFilter = NULL) {
   else if (isContentType(response, "text/html")) {
 
     body <- regexExtract(".*?<body>(.*?)</body>.*", response$content)
-    if (response$status >= 200 && response$status < 400){
+    if (response$status >= 200 && response$status < 400) {
       # Good response, return the body if we have one, or the content if not
-      if (!is.null(body)){
+      if (!is.null(body)) {
         body
       } else{
         response$content
