@@ -10,7 +10,7 @@
 #' @param account Account name. If a single account is registered on the
 #'   system then this parameter can be omitted.
 #' @param server Server name. Required only if you use the same account name on
-#'   multiple servers (see \code{\link{servers}})
+#'   multiple servers (see [servers()])
 #' @param redeploy Re-deploy application after its been configured.
 #' @param size Configure application instance size
 #' @param instances Configure number of application instances
@@ -20,9 +20,10 @@
 #' # set instance size for an application
 #' configureApp("myapp", size="xlarge")
 #' }
-#' @seealso \code{\link{applications}}, \code{\link{deployApp}}
+#' @seealso [applications()], [deployApp()]
+#' @note This function works only for ShinyApps servers.
 #' @export
-configureApp <- function(appName, appDir=getwd(), account = NULL, server = NULL,
+configureApp <- function(appName, appDir = getwd(), account = NULL, server = NULL,
                          redeploy = TRUE, size = NULL,
                          instances = NULL, logLevel = c("normal", "quiet", "verbose")) {
 
@@ -33,35 +34,37 @@ configureApp <- function(appName, appDir=getwd(), account = NULL, server = NULL,
   displayStatus <- displayStatus(identical(logLevel, "quiet"))
 
   # some properties may required a rebuild to take effect
-  rebuildRequired = FALSE
+  rebuildRequired <- FALSE
 
   # get a list of properties to set
   properties <- list()
-  if (! is.null(size) ) {
-    properties[[ "application.instances.template" ]] = size
+  if (! is.null(size)) {
+    properties[["application.instances.template"]] <- size
   }
-  if (! is.null(instances) ) {
-    properties[[ "application.instances.count" ]] = instances
+  if (! is.null(instances)) {
+    properties[["application.instances.count"]] <- instances
   }
 
   # set application properties
   serverDetails <- serverInfo(accountDetails$server)
-  lucid <- lucidClient(serverDetails$url, accountDetails)
-
   client <- clientForAccount(accountDetails)
   for (i in names(properties)) {
     propertyName <- i
     propertyValue <- properties[[i]]
-    if (identical(client, lucid))
-      lucid$setApplicationProperty(application$id, propertyName, propertyValue)
-    else
+
+    # dispatch to the appropriate client implementation
+    if (is.function(client$configureApplication))
       client$configureApplication(application$id, propertyName, propertyValue)
+    else if (is.function(client$setApplicationProperty))
+      client$setApplicationProperty(application$id, propertyName, propertyValue)
+    else
+      stop("Server ", accountDetails$server, " has no appropriate configuration method.")
   }
 
   # redeploy application if requested
   if (redeploy) {
     if (length(properties) > 0) {
-      deployApp(appDir=appDir, appName=appName, account=account, logLevel=logLevel, upload=rebuildRequired)
+      deployApp(appDir = appDir, appName = appName, account = account, logLevel = logLevel, upload = rebuildRequired)
     }
     else
     {
@@ -102,8 +105,7 @@ setProperty <- function(propertyName, propertyValue, appPath = getwd(),
   # resolve the application target and target account info
   target <- deploymentTarget(appPath, appName, NULL, NULL, account)
   accountDetails <- accountInfo(target$account)
-  serverDetails <- serverInfo(accountDetails$server)
-  lucid <- lucidClient(serverDetails$url, accountDetails)
+  lucid <- lucidClientForAccount(accountDetails)
   application <- getAppByName(lucid, accountDetails, target$appName)
   if (is.null(application))
     stop("No application found. Specify the application's directory, name, ",
@@ -138,14 +140,13 @@ setProperty <- function(propertyName, propertyValue, appPath = getwd(),
 #'
 #' }
 #' @export
-unsetProperty <- function(propertyName, appPath = getwd(), appName=NULL,
-                          account = NULL, force=FALSE) {
+unsetProperty <- function(propertyName, appPath = getwd(), appName = NULL,
+                          account = NULL, force = FALSE) {
 
   # resolve the application target and target account info
   target <- deploymentTarget(appPath, appName, NULL, NULL, account)
   accountDetails <- accountInfo(target$account)
-  serverDetails <- serverInfo(accountDetails$server)
-  lucid <- lucidClient(serverDetails$url, accountDetails)
+  lucid <- lucidClientForAccount(accountDetails)
   application <- getAppByName(lucid, accountInfo, target$appName)
   if (is.null(application))
     stop("No application found. Specify the application's directory, name, ",
@@ -175,8 +176,7 @@ showProperties <- function(appPath = getwd(), appName = NULL, account = NULL) {
   # determine the log target and target account info
   target <- deploymentTarget(appPath, appName, NULL, NULL, account)
   accountDetails <- accountInfo(target$account)
-  serverDetails <- serverInfo(accountDetails$server)
-  lucid <- lucidClient(serverDetails$url, accountDetails)
+  lucid <- lucidClientForAccount(accountDetails)
   application <- getAppByName(lucid, accountDetails, target$appName)
   if (is.null(application))
     stop("No application found. Specify the application's directory, name, ",
