@@ -17,25 +17,21 @@ findConnect <- function() {
   }
 }
 
-isConnectRunning <- function() {
-  any(grepl("./bin/connect", system2("ps", "-a", stdout = TRUE), fixed = TRUE))
-}
-
 test_that("Users API", {
 
   skip_on_cran()
   skip_on_os("windows")
-  skip_if(!isConnectRunning())
+  skip("connect user test skipped.")
 
   ## rm db/*.db
   server <- getDefaultServer(local = TRUE)
 
   connect <- connectClient(server$url, list())
-  id <- paste(as.hexmode(sample(256, bytes)-1), collapse="")
+  id <- paste(as.hexmode(sample(256, bytes) - 1), collapse = "")
 
   # add a user
   record <- userRecord(
-    email = paste0("user", id ,"@gmail.com"),
+    email = paste0("user", id, "@gmail.com"),
     username = paste0("user", id),
     first_name = "User",
     last_name = "Resu",
